package com.serrano.aureo.lineaverde;

import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.ParcelFileDescriptor;
import android.provider.MediaStore;
import android.support.v4.app.NavUtils;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.Toast;

import com.google.android.gms.maps.model.LatLng;
import com.serrano.aureo.lineaverde.utils.ExternalFile;

import java.io.File;
import java.io.FileDescriptor;
import java.io.InputStream;

public class AvisoFoto extends AppCompatActivity
{

    private LatLng location = null;
    private static int PICK_IMAGE_CODE = 1;
    private static int CAPTURE_IMAGE_CODE = 2;


    // Views
    private Button mButtonGallery;
    private Button mButtonFoto;
    private ImageView mImageView;

    //Selected image
    private Bitmap selectedImageBmp = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_aviso_foto);

        // Set views
        mButtonGallery = (Button) findViewById(R.id.botonGallery);
        mButtonFoto = (Button) findViewById(R.id.botonFoto);
        mImageView = (ImageView) findViewById(R.id.avisoFoto);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);

        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        location = (LatLng) this.getIntent().getParcelableExtra("location");

        mButtonGallery.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                // Create intent to Open Image applications
                Intent galleryIntent = new Intent(Intent.ACTION_PICK,
                        android.provider.MediaStore.Images.Media.EXTERNAL_CONTENT_URI);

                // Start the Intent
                startActivityForResult(galleryIntent, PICK_IMAGE_CODE);
            }
        });

        mButtonFoto.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                if(checkCameraHardware(getApplicationContext()))
                {
                    // create Intent to take a picture and return control to the calling application
                    Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);

                    // start the image capture Intent
                    startActivityForResult(intent, CAPTURE_IMAGE_CODE);
                }
                else
                {
                    Toast.makeText(getApplicationContext(), R.string.error_no_camera,
                            Toast.LENGTH_LONG).show();
                }
            }
        });

        //Borrar la foto antigua si la hubiera
        File img;
        if((img = ExternalFile.hasImageFile(AvisoFoto.this)) != null)
        {
            ExternalFile.deleteImageFile(AvisoFoto.this, img);
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data)
    {
        //super.onActivityResult(requestCode, resultCode, data);

        try {
            // When an Image is picked
            if ( (requestCode == PICK_IMAGE_CODE || requestCode == CAPTURE_IMAGE_CODE) && resultCode == RESULT_OK
                    && data != null)
            {
                // Get the Image from data

                final Uri imageUri = data.getData();

                final File imgFile = ExternalFile.getFilefromUri(imageUri, AvisoFoto.this);
                final Bitmap selectedImage = ExternalFile.decodeFile(imgFile);

                //save the uri of the image for later use
                selectedImageBmp = selectedImage;

                mImageView.setImageBitmap(selectedImage);

                invalidateOptionsMenu();

            } else {
                Toast.makeText(this, R.string.error_picked_text,
                        Toast.LENGTH_LONG).show();
            }
        } catch (Exception e)
        {
            Log.e("MIRAR",e.getMessage());
            Toast.makeText(this, R.string.error_text, Toast.LENGTH_LONG)
                    .show();
        }

    }

    /** Check if this device has a camera */
    private boolean checkCameraHardware(Context context)
    {
        PackageManager pm = context.getPackageManager();

        if (pm.hasSystemFeature(PackageManager.FEATURE_CAMERA))
        {
            // this device has a camera
            return true;
        } else {
            // no camera on this device
            return false;
        }
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu)
    {
        if (selectedImageBmp != null)
        {
            MenuItem fotoSig = menu.findItem(R.id.action_fotoSig);
            fotoSig.setEnabled(true);
        }

        return true;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_foto, menu);
        MenuItem fotoSig = menu.findItem(R.id.action_fotoSig);
        fotoSig.setEnabled(false);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // Respond to the action bar's Up/Home button
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;

            case R.id.action_fotoSig:
                goAvisoOpsActivity();
                return true;
        }
        return super.onOptionsItemSelected(item);
    }

    private void goAvisoOpsActivity()
    {
        //Save the imagen
        if(selectedImageBmp != null)
        {
            ExternalFile.saveImageFile(AvisoFoto.this, selectedImageBmp);

            Intent navIntent = new Intent(AvisoFoto.this, AvisoObs.class);
            navIntent.putExtra("location", location);
            startActivity(navIntent);
        }
    }

}
