package com.serrano.aureo.lineaverde;

import android.content.Intent;
import android.content.SharedPreferences;
import android.support.v4.app.FragmentActivity;
import android.os.Bundle;
import android.support.v4.app.NavUtils;
import android.support.v7.app.ActionBarActivity;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.MapFragment;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

public class AvisoMap extends AppCompatActivity implements OnMapReadyCallback {

    private GoogleMap mMap;
    private Marker avisoMark = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_aviso_map);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);

        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        MapFragment mapFragment = (MapFragment) getFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);
    }


    /**
     * Manipulates the map once available.
     * This callback is triggered when the map is ready to be used.
     * This is where we can add markers or lines, add listeners or move the camera. In this case,
     * we just add a marker near Sydney, Australia.
     * If Google Play services is not installed on the device, the user will be prompted to install
     * it inside the SupportMapFragment. This method will only be triggered once the user has
     * installed Google Play services and returned to the app.
     */
    @Override
    public void onMapReady(GoogleMap googleMap) {
        mMap = googleMap;

        //I activate the MyLocation for the map, so It can read the location of the terminal
        mMap.setMyLocationEnabled(true);
        mMap.getUiSettings().setMyLocationButtonEnabled(true);
        mMap.setMapType(GoogleMap.MAP_TYPE_TERRAIN);
        mMap.getUiSettings().setZoomControlsEnabled(true);


        LatLng argamasilla = new LatLng(39.1286074, -3.0901944);
        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(argamasilla, 18));


        //Create the aviso Marker
        mMap.setOnMapLongClickListener(new GoogleMap.OnMapLongClickListener() {
            @Override
            public void onMapLongClick(LatLng latLng) {
                //If a previous car marker exist, remove it
                if (avisoMark != null) {
                    avisoMark.remove();
                }

                avisoMark = mMap.addMarker(new MarkerOptions()
                        .position(latLng)
                        .draggable(false)
                        .anchor((float) 0.5, (float) 0.5)
                        .icon(BitmapDescriptorFactory.fromResource(R.drawable.ic_aviso_mark)));

                //enable the menuitem sig
                invalidateOptionsMenu();
            }
        });


    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu)
    {
        if (avisoMark != null)
        {
            MenuItem mapSig = menu.findItem(R.id.action_mapSig);
            mapSig.setEnabled(true);
        }

        return true;
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_map, menu);
        MenuItem mapSig = menu.findItem(R.id.action_mapSig);
        mapSig.setEnabled(false);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // Respond to the action bar's Up/Home button
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;

            case R.id.action_mapSig:
                goAvisoFotoActivity();
                return true;
        }
        return super.onOptionsItemSelected(item);
    }

    private void goAvisoFotoActivity()
    {
        Intent navIntent = new Intent(AvisoMap.this, AvisoFoto.class);
        navIntent.putExtra("location", avisoMark.getPosition());
        startActivity(navIntent);
    }
}
