package com.serrano.aureo.lineaverde;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.provider.Settings;
import android.support.v4.app.NavUtils;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.telephony.TelephonyManager;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.maps.model.LatLng;
import com.parse.ParseException;
import com.parse.ParseFile;
import com.parse.ParseGeoPoint;
import com.parse.ParseObject;
import com.parse.SaveCallback;
import com.serrano.aureo.lineaverde.entities.Aviso;
import com.serrano.aureo.lineaverde.utils.ExternalFile;
import com.serrano.aureo.lineaverde.utils.ParseUtils;

import java.io.File;

public class AvisoObs extends AppCompatActivity {

    private LatLng location = null;
    //Selected image
    private File selectedImageFile = null;
    private EditText obsText;

    private ProgressDialog progreso = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_aviso_obs);

        obsText = (EditText) findViewById(R.id.obsText);
        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);

        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        location = (LatLng) this.getIntent().getParcelableExtra("location");

        selectedImageFile = ExternalFile.hasImageFile(AvisoObs.this);

        progreso = new ProgressDialog(AvisoObs.this);
        progreso.setIndeterminate(true);
        progreso.setMessage("Enviando...");
        progreso.setProgressStyle(ProgressDialog.STYLE_SPINNER);

    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_obs, menu);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // Respond to the action bar's Up/Home button
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;

            case R.id.action_opsEnvia:
                enviaDatos();
                return true;
        }
        return super.onOptionsItemSelected(item);
    }

    private void enviaDatos()
    {

        TelephonyManager tMgr =(TelephonyManager) this.getSystemService(Context.TELEPHONY_SERVICE);
        String phoneNumber = tMgr.getLine1Number();

        String obs = obsText.getText().toString();

        if (selectedImageFile != null && selectedImageFile.length()<2000000)
        {
            ParseFile parseImage = new ParseFile(selectedImageFile);

            final Aviso aviso = new Aviso();

            aviso.defaultValues();

            String android_id = Settings.Secure.getString(this.getApplicationContext().getContentResolver(),
                    Settings.Secure.ANDROID_ID);

            aviso.put(Aviso.AVISO_ANDROID,android_id);
            aviso.put(Aviso.AVISO_TELEFONO, phoneNumber);
            aviso.put(Aviso.AVISO_LOCALIZACION, new ParseGeoPoint(location.latitude, location.longitude));
            aviso.put(Aviso.AVISO_DESCRIPCION, obs);
            aviso.put(Aviso.AVISO_FOTO, parseImage);

            //progreso
            progreso.show();

            new Thread(new Runnable() {
                @Override
                public void run()
                {
                    ParseUtils.saveAvisoToServer(aviso);

                    progreso.dismiss();
                    goMainActivity();
                }
            }).start();
        }
        else
        {
            Toast.makeText(AvisoObs.this, "Imagen demasiado grande, baje su tamaño o calidad", Toast.LENGTH_LONG).show();
            goMainActivity();
        }


    }


    private void goMainActivity()
    {
        //Toast.makeText(AvisoObs.this, "Aviso enviado", Toast.LENGTH_SHORT).show();
        Intent navIntent = new Intent(AvisoObs.this, MainActivity.class).addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        startActivity(navIntent);
    }
}
