package com.serrano.aureo.lineaverde;

import android.support.v4.app.NavUtils;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.widget.ImageView;
import android.widget.TextView;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.MapFragment;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.MarkerOptions;
import com.serrano.aureo.lineaverde.entities.Aviso;
import com.serrano.aureo.lineaverde.utils.ParseUtils;

import java.text.SimpleDateFormat;

public class DetailActivity extends AppCompatActivity implements OnMapReadyCallback
{

    private ImageView foto;
    private TextView textTel;
    private TextView textRec;
    private TextView textCur;
    private TextView textRes;
    private TextView textDesc;
    private LatLng location;
    private GoogleMap mMap;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detail);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);

        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        foto = (ImageView) findViewById(R.id.fotoView);
        textTel = (TextView) findViewById(R.id.editTextTel);
        textRec= (TextView) findViewById(R.id.editTextRec);
        textCur = (TextView) findViewById(R.id.editTextCur);
        textRes = (TextView) findViewById(R.id.editTextRes);
        textDesc = (TextView) findViewById(R.id.textViewDesc);

        //aviso ID
        String avisoID = getIntent().getStringExtra("AvisoID");

        Aviso aviso = ParseUtils.getAvisoByID(avisoID);

        populateView(aviso);

        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        MapFragment mapFragment = (MapFragment) getFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

    }

    private void populateView(Aviso aviso)
    {
        foto.setImageBitmap(aviso.getAvisoFoto());
        textTel.setText(aviso.getAvisoTelefono());
        textRec.setText(aviso.getAvisoFenvioString());
        textCur.setText(aviso.getAvisoFencursoString());
        textRes.setText(aviso.getAvisoFresueltoString());
        textDesc.setText(aviso.getAvisoDescripcion());
        location = aviso.getAvisoLocalizacion();
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // Respond to the action bar's Up/Home button
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;

        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onMapReady(GoogleMap googleMap)
    {
        mMap = googleMap;
        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(location, 18));

        mMap.addMarker(new MarkerOptions()
                .position(location)
                .draggable(false)
                .anchor((float) 0.5, (float) 0.5)
                .icon(BitmapDescriptorFactory.fromResource(R.drawable.ic_aviso_mark)));

    }
}
