package com.serrano.aureo.lineaverde;

import android.app.ProgressDialog;
import android.graphics.Color;
import android.support.v4.app.NavUtils;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.MapFragment;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.MarkerOptions;
import com.serrano.aureo.lineaverde.entities.Aviso;
import com.serrano.aureo.lineaverde.utils.ParseUtils;

import java.util.Date;
import java.util.GregorianCalendar;

public class DetailProActivity extends AppCompatActivity implements OnMapReadyCallback
{

    private ImageView foto;
    private TextView textTel;
    private TextView textRec;
    private TextView textCur;
    private TextView textRes;
    private TextView textDesc;
    private LatLng location;
    private GoogleMap mMap;
    private Button botonRecibido;
    private Button botonEnCurso;
    private Button botonResuelto;

    private ProgressDialog progreso;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detail_pro);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);

        setSupportActionBar(toolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        foto = (ImageView) findViewById(R.id.fotoView);
        textTel = (TextView) findViewById(R.id.editTextTel);
        textRec= (TextView) findViewById(R.id.editTextRec);
        textCur = (TextView) findViewById(R.id.editTextCur);
        textRes = (TextView) findViewById(R.id.editTextRes);
        textDesc = (TextView) findViewById(R.id.textViewDesc);

        botonRecibido = (Button) findViewById(R.id.botonRecibido);
        botonEnCurso = (Button) findViewById(R.id.botonEnCurso);
        botonResuelto = (Button) findViewById(R.id.botonResuelto);

        //aviso ID
        String avisoID = getIntent().getStringExtra("AvisoID");

        final Aviso aviso = ParseUtils.getAvisoByID(avisoID);

        populateView(aviso);

        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        MapFragment mapFragment = (MapFragment) getFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

        progreso = new ProgressDialog(DetailProActivity.this);
        progreso.setIndeterminate(true);
        progreso.setMessage("Enviando...");
        progreso.setProgressStyle(ProgressDialog.STYLE_SPINNER);

        botonRecibido.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                //cambiar colores
                botonRecibido.setBackgroundColor(Color.WHITE);
                botonEnCurso.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                botonResuelto.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));

                //cambia el estado
                aviso.put(Aviso.AVISO_ESTADO,1);
                //La fecha de recepción no cambia

                //progreso
                progreso.show();

                new Thread(new Runnable() {
                    @Override
                    public void run()
                    {
                        ParseUtils.saveAvisoToServer(aviso);

                        progreso.dismiss();
                    }
                }).start();
            }
        });

        botonEnCurso.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                //cambiar colores
                botonRecibido.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                botonEnCurso.setBackgroundColor(Color.WHITE);
                botonResuelto.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));

                //cambia el estado
                aviso.put(Aviso.AVISO_ESTADO,2);

                Date fecha = new Date();

                //cambia la fecha
                aviso.put(Aviso.AVISO_FENCURSO, fecha);
                textCur.setText(aviso.getAvisoFencursoString());


                //progreso
                progreso.show();

                new Thread(new Runnable() {
                    @Override
                    public void run()
                    {
                        ParseUtils.saveAvisoToServer(aviso);

                        progreso.dismiss();
                    }
                }).start();
            }
        });

        botonResuelto.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                //cambiar colores
                botonRecibido.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                botonEnCurso.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                botonResuelto.setBackgroundColor(Color.WHITE);

                //cambia el estado
                aviso.put(Aviso.AVISO_ESTADO,3);

                Date fecha = new Date();
                //cambia la fecha
                aviso.put(Aviso.AVISO_FRESUELTO, fecha);
                textRes.setText(aviso.getAvisoFresueltoString());

                //progreso
                progreso.show();

                new Thread(new Runnable() {
                    @Override
                    public void run()
                    {
                        ParseUtils.saveAvisoToServer(aviso);

                        progreso.dismiss();
                    }
                }).start();
            }
        });

    }

    private void populateView(Aviso aviso)
    {
        foto.setImageBitmap(aviso.getAvisoFoto());
        textTel.setText(aviso.getAvisoTelefono());
        textRec.setText(aviso.getAvisoFenvioString());
        textCur.setText(aviso.getAvisoFencursoString());
        textRes.setText(aviso.getAvisoFresueltoString());
        textDesc.setText(aviso.getAvisoDescripcion());
        location = aviso.getAvisoLocalizacion();

        //colores del boton
        switch (aviso.getAvisoEstado())
        {
            case 1:
                    botonRecibido.setBackgroundColor(Color.WHITE);
                    botonEnCurso.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                    botonResuelto.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                break;

            case 2:
                    botonRecibido.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                    botonEnCurso.setBackgroundColor(Color.WHITE);
                    botonResuelto.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                break;

            case 3:
                    botonRecibido.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                    botonEnCurso.setBackgroundColor(ContextCompat.getColor(getApplicationContext(), R.color.colorPrimary));
                    botonResuelto.setBackgroundColor(Color.WHITE);
                break;
        }

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            // Respond to the action bar's Up/Home button
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;

        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onMapReady(GoogleMap googleMap)
    {
        mMap = googleMap;
        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(location, 18));

        mMap.addMarker(new MarkerOptions()
                .position(location)
                .draggable(false)
                .anchor((float) 0.5, (float) 0.5)
                .icon(BitmapDescriptorFactory.fromResource(R.drawable.ic_aviso_mark)));

    }

}
