package com.serrano.aureo.lineaverde;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.provider.Settings;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.serrano.aureo.lineaverde.adapter.AvisosAdapter;
import com.serrano.aureo.lineaverde.entities.Aviso;
import com.serrano.aureo.lineaverde.utils.ParseUtils;

import java.util.List;

public class MainActivity extends AppCompatActivity
{
    private ListView list;
    private List<Aviso> avisos;
    private AvisosAdapter avisosAdapter;

    private ProgressDialog progreso = null;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);
        toolbar.setNavigationIcon(R.drawable.ic_action_lock);

        list = (ListView) findViewById(R.id.list);

        setSupportActionBar(toolbar);

        list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id)
            {
                Aviso aviso = (Aviso) list.getItemAtPosition(position);

                String avisoID = aviso.getObjectId();

                Intent intent = new Intent(MainActivity.this, DetailActivity.class);

                //Pass the objectID to the detail activity
                intent.putExtra("AvisoID", avisoID);
                startActivity(intent);

            }
        });

        list.setOnItemLongClickListener(new AdapterView.OnItemLongClickListener() {
            @Override
            public boolean onItemLongClick(AdapterView<?> parent, View view, int position, long id)
            {

                final Aviso aviso = (Aviso) list.getItemAtPosition(position);

                new AlertDialog.Builder(MainActivity.this)
                        .setIcon(R.drawable.ic_action_alerta)
                        .setTitle("Alerta")
                        .setMessage("¿Esta seguro que desea borrar este aviso de su lista?")
                        .setPositiveButton("Si", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which)
                            {
                                //cambiar visibilidad
                                aviso.put(Aviso.AVISO_VISIBLE, false);

                                new Thread(new Runnable() {
                                    @Override
                                    public void run()
                                    {
                                        ParseUtils.saveAvisoToServer(aviso);
                                    }
                                }).start();

                                avisosAdapter.remove(aviso);
                            }
                        })
                        .setNegativeButton("No",null)
                        .show();

                return true;
            }
        });

        progreso = new ProgressDialog(MainActivity.this);
        progreso.setIndeterminate(true);
        progreso.setMessage("Cargando...");
        progreso.setProgressStyle(ProgressDialog.STYLE_SPINNER);

        avisos = null;

        progreso.show();

        String android_id = Settings.Secure.getString(this.getApplicationContext().getContentResolver(),
                Settings.Secure.ANDROID_ID);
        //get the avisos
        avisos = ParseUtils.getAvisosByAndroidID(android_id);

        progreso.dismiss();

        //Check if exists data

        if(avisos != null)
        {
            if (avisos.size() > 0)
            {
                // Init adapter
                avisosAdapter = new AvisosAdapter(this, avisos);
                list.setAdapter(avisosAdapter);
            } else {
                Toast.makeText(MainActivity.this, R.string.errorNoData, Toast.LENGTH_LONG).show();
            }
        }
        else
        {
            Toast.makeText(MainActivity.this, R.string.errorNoData, Toast.LENGTH_LONG).show();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu)
    {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            case R.id.action_nuevo:
                goAvisoMapActivity();
                return true;
            case android.R.id.home:
                //Ir a Login
                goLoginActivity();
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    private void goAvisoMapActivity()
    {
        Intent navIntent = new Intent(MainActivity.this, AvisoMap.class);

        startActivity(navIntent);
    }

    private void goLoginActivity()
    {
        Intent navIntent = new Intent(MainActivity.this, LoginActivity.class);

        startActivity(navIntent);
    }

}