package com.serrano.aureo.lineaverde;

import android.app.DatePickerDialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.CheckBox;
import android.widget.DatePicker;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.ListView;
import android.widget.Toast;

import com.serrano.aureo.lineaverde.adapter.AvisosAdapter;
import com.serrano.aureo.lineaverde.entities.Aviso;
import com.serrano.aureo.lineaverde.utils.ParseUtils;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

public class MainProActivity extends AppCompatActivity
{

    private ListView list;
    private List<Aviso> avisos;
    private AvisosAdapter avisosAdapter;
    private EditText editDesde;
    private EditText editHasta;
    private ImageButton botonBuscar;
    private CheckBox resueltosOnly;

    private ProgressDialog progreso = null;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main_pro);

        Toolbar toolbar = (Toolbar) findViewById(R.id.appbar);
        toolbar.setNavigationIcon(R.drawable.ic_action_close);

        list = (ListView) findViewById(R.id.list);

        editDesde = (EditText) findViewById(R.id.editDateDesde);
        editHasta = (EditText) findViewById(R.id.editDateHasta);
        botonBuscar = (ImageButton) findViewById(R.id.botonBuscar);
        resueltosOnly = (CheckBox) findViewById(R.id.checkResueltosOnly);



        setSupportActionBar(toolbar);

        list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id)
            {
                Aviso aviso = (Aviso) list.getItemAtPosition(position);

                String avisoID = aviso.getObjectId();

                Intent intent = new Intent(MainProActivity.this, DetailProActivity.class);

                //Pass the objectID to the detail activity
                intent.putExtra("AvisoID", avisoID);
                startActivity(intent);

            }
        });

        progreso = new ProgressDialog(MainProActivity.this);
        progreso.setIndeterminate(true);
        progreso.setMessage("Cargando...");
        progreso.setProgressStyle(ProgressDialog.STYLE_SPINNER);

        setDays();

        Date desde = new Date();
        Date hasta = new Date();
        SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy");

        try
        {
            desde = df.parse(editDesde.getText().toString());
            hasta = df.parse(editHasta.getText().toString());
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(hasta);
            calendar.add(Calendar.DAY_OF_MONTH,1);
            hasta = calendar.getTime();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }



        avisos = null;

        //Los avisos del ultimo mes
        avisos = ParseUtils.getAvisosSoloNoResueltosFecha(desde, hasta);

        //Check if exists data

        if(avisos != null)
        {
            if (avisos.size() > 0)
            {
                // Init adapter
                avisosAdapter = new AvisosAdapter(this, avisos);
                list.setAdapter(avisosAdapter);
            } else {
                Toast.makeText(MainProActivity.this, R.string.errorNoData, Toast.LENGTH_LONG).show();
            }
        }
        else
        {
            Toast.makeText(MainProActivity.this, R.string.errorNoData, Toast.LENGTH_LONG).show();
        }

        editDesde.setOnClickListener(new View.OnClickListener()
        {
            @Override
            public void onClick(View v)
            {
                final SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy");
                final Date hoyDate;
                final Calendar hoy = Calendar.getInstance();;
                try {
                    hoyDate = df.parse(editDesde.getText().toString());
                    hoy.setTime(hoyDate);
                } catch (ParseException e) {
                    e.printStackTrace();
                }

                new DatePickerDialog(MainProActivity.this,new DatePickerDialog.OnDateSetListener() {
                    @Override
                    public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth)
                    {
                        try
                        {
                            Date dia = df.parse(dayOfMonth+"-"+(monthOfYear + 1) + "-" + year);
                            editDesde.setText(df.format(dia));

                        } catch (ParseException e)
                        {
                            e.printStackTrace();
                        }
                    }
                },hoy.get(Calendar.YEAR),hoy.get(Calendar.MONTH),hoy.get(Calendar.DAY_OF_MONTH)).show();
            }
        });

        editHasta.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                final SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy");
                final Date hoyDate;
                final Calendar hoy = Calendar.getInstance();;
                try {
                    hoyDate = df.parse(editHasta.getText().toString());
                    hoy.setTime(hoyDate);
                } catch (ParseException e) {
                    e.printStackTrace();
                }

                new DatePickerDialog(MainProActivity.this,new DatePickerDialog.OnDateSetListener() {
                    @Override
                    public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth)
                    {
                        try
                        {
                            Date dia = df.parse(dayOfMonth+"-"+(monthOfYear + 1) + "-" + year);
                            editHasta.setText(df.format(dia));

                        } catch (ParseException e)
                        {
                            e.printStackTrace();
                        }
                    }
                },hoy.get(Calendar.YEAR),hoy.get(Calendar.MONTH),hoy.get(Calendar.DAY_OF_MONTH)).show();
            }
        });

        botonBuscar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v)
            {
                Date desde = new Date();
                Date hasta = new Date();
                SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy");

                try
                {
                    desde = df.parse(editDesde.getText().toString());
                    hasta = df.parse(editHasta.getText().toString());
                }
                catch (Exception ex)
                {
                    ex.printStackTrace();
                }

                Calendar calendar = Calendar.getInstance();
                calendar.setTime(hasta);
                calendar.add(Calendar.DAY_OF_MONTH,1);
                hasta = calendar.getTime();

                final List<Aviso> lista = null;

                avisosAdapter.clear();

                progreso.show();

                if(resueltosOnly.isChecked())
                {
                    new AsyncTask<Date, Void, List<Aviso>>() {
                        @Override
                        protected List<Aviso> doInBackground(Date... params) {
                            List<Aviso> avisos;

                            avisos = ParseUtils.getAvisosSoloNoResueltosFecha(params[0], params[1]);

                            return avisos;
                        }

                        @Override
                        protected void onPostExecute(List<Aviso> avisos) {
                            avisosAdapter.addAll(avisos);
                            progreso.dismiss();
                        }
                    }.execute(desde, hasta);
                }
                else
                {
                    new AsyncTask<Date, Void, List<Aviso>>() {
                        @Override
                        protected List<Aviso> doInBackground(Date... params) {
                            List<Aviso> avisos;

                            avisos = ParseUtils.getAvisosFecha(params[0], params[1]);

                            return avisos;
                        }

                        @Override
                        protected void onPostExecute(List<Aviso> avisos) {
                            avisosAdapter.addAll(avisos);
                            progreso.dismiss();
                        }
                    }.execute(desde, hasta);
                }
            }
        });



    }

    private void setDays()
    {
        SimpleDateFormat dt = new SimpleDateFormat("dd-MM-yyyy");
        Calendar hoy = Calendar.getInstance();

        editHasta.setText(dt.format(hoy.getTime()));
        hoy.add(Calendar.MONTH,-1);
        editDesde.setText(dt.format(hoy.getTime()));

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            case android.R.id.home:
                this.finish();
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

}
