package com.serrano.aureo.lineaverde.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.serrano.aureo.lineaverde.R;
import com.serrano.aureo.lineaverde.entities.Aviso;

import java.util.List;

public class AvisosAdapter extends ArrayAdapter<Aviso>
{
    private Context context;
    private List<Aviso> avisos;

    private static class ViewHolder {
        ImageView icono;
        TextView fecha;
        TextView desc;
    }


    public AvisosAdapter(Context context, List<Aviso> avisos)
    {
        super(context, R.layout.aviso_item, avisos);
        this.context = context;
        this.avisos = avisos;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent)
    {
        // Get the data for this position
        Aviso aviso = getItem(position);

        //Use a ViewHolder to improve performance
        ViewHolder viewHolder;

        // Check if an existing view is being reused, otherwise inflate the view
        if (convertView == null)
        {
            viewHolder = new ViewHolder();
            LayoutInflater inflater = LayoutInflater.from(getContext());
            convertView = inflater.inflate(R.layout.aviso_item, parent, false);
            viewHolder.fecha = (TextView) convertView.findViewById(R.id.avisoFecha);
            viewHolder.desc = (TextView) convertView.findViewById(R.id.avisoDesc);
            viewHolder.icono = (ImageView) convertView.findViewById(R.id.iconoView);
            convertView.setTag(viewHolder);
        }
        else
        {
            viewHolder = (ViewHolder) convertView.getTag();
        }

        // Populate the data into the template view using the data object

        int estado = aviso.getAvisoEstado();

        Bitmap icono;

        switch (estado)
        {
            case 1:
                    icono = BitmapFactory.decodeResource(getContext().getResources(), R.mipmap.ic_alerta);
                break;

            case 2:
                    icono = BitmapFactory.decodeResource(getContext().getResources(), R.mipmap.ic_encurso);
                break;

            case 3:
                    icono = BitmapFactory.decodeResource(getContext().getResources(), R.mipmap.ic_ok);
                break;

            default:
                    icono = BitmapFactory.decodeResource(getContext().getResources(), R.mipmap.ic_alerta);
                break;
        }

        viewHolder.icono.setImageBitmap(icono);

        viewHolder.fecha.setText(aviso.getLastDate());
        viewHolder.desc.setText(aviso.getAvisoDescripcion());

        // Return the completed view to render on screen
        return convertView;
    }




}
