package com.serrano.aureo.lineaverde.entities;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

import com.google.android.gms.maps.model.LatLng;
import com.parse.ParseClassName;
import com.parse.ParseException;
import com.parse.ParseFile;
import com.parse.ParseGeoPoint;
import com.parse.ParseObject;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.concurrent.Exchanger;


@ParseClassName("Avisos")
public class Aviso extends ParseObject
{
    public static final String AVISO_ANDROID = "androId";
    public static final String AVISO_TELEFONO = "telefono";
    public static final String AVISO_FOTO = "foto";
    public static final String AVISO_LOCALIZACION = "location";
    public static final String AVISO_DESCRIPCION = "descripcion";
    public static final String AVISO_FENVIO = "fenvio";
    public static final String AVISO_FENCURSO = "fencurso";
    public static final String AVISO_FRESUELTO = "fresuelto";
    public static final String AVISO_ESTADO = "estado";
    public static final String AVISO_VISIBLE = "visible";


    public Aviso()
    {

    }

    public  void defaultValues()
    {
        Date fecha = new Date();
        DateFormat df = new SimpleDateFormat ("dd-MM-yyyy");

        try {
            this.put(AVISO_TELEFONO,"");
            this.put(AVISO_DESCRIPCION,"");
            this.put(AVISO_FENVIO, fecha);
            this.put(AVISO_FENCURSO, df.parse("01-01-2000"));
            this.put(AVISO_FRESUELTO, df.parse("01-01-2000"));
            this.put(AVISO_ESTADO, 1);
            this.put(AVISO_VISIBLE, true);
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
    }

    public String getAvisoAndroid()
    {
        return getString(AVISO_ANDROID);
    }

    public String getAvisoDescripcion() {
        return getString(AVISO_DESCRIPCION);
    }

    public int getAvisoEstado() {
        return getInt(AVISO_ESTADO);
    }

    public Date getAvisoFencurso() {
        return getDate(AVISO_FENCURSO);
    }

    public String getAvisoFencursoString()
    {
        Date nula = null;
        Date fecha;
        SimpleDateFormat dt = new SimpleDateFormat("dd-MM-yyyy");
        try
        {
            nula = dt.parse("01-01-2000");
        } catch (java.text.ParseException e)
        {
            e.printStackTrace();
        }
        fecha = getDate(AVISO_FENCURSO);

        if (fecha.equals(nula))
        {
            return "";
        }
        else
        {
            return dt.format(fecha);
        }
    }

    public String getAvisoFenvioString()
    {
        Date nula = null;
        Date fecha;
        SimpleDateFormat dt = new SimpleDateFormat("dd-MM-yyyy");
        try
        {
            nula = dt.parse("01-01-2000");
        } catch (java.text.ParseException e)
        {
            e.printStackTrace();
        }
        fecha = getDate(AVISO_FENVIO);

        if (fecha.equals(nula))
        {
            return "";
        }
        else
        {
            return dt.format(fecha);
        }
    }

    public Date getAvisoFenvio() {
        return getDate(AVISO_FENVIO);
    }

    public Bitmap getAvisoFoto() {
        Bitmap bitmap = null;
        try {
            byte[] bitmapdata = getParseFile(AVISO_FOTO).getData();
            bitmap = BitmapFactory.decodeByteArray(bitmapdata, 0, bitmapdata.length);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return bitmap;
    }

    public Date getAvisoFresuelto() {
        return getDate(AVISO_FRESUELTO);
    }

    public String getAvisoFresueltoString()
    {
        Date nula = null;
        Date fecha;
        SimpleDateFormat dt = new SimpleDateFormat("dd-MM-yyyy");
        try
        {
            nula = dt.parse("01-01-2000");
        } catch (java.text.ParseException e)
        {
            e.printStackTrace();
        }
        fecha = getDate(AVISO_FRESUELTO);

        if (fecha.equals(nula))
        {
            return "";
        }
        else
        {
            return dt.format(fecha);
        }
    }

    public LatLng getAvisoLocalizacion()
    {

        ParseGeoPoint point = getParseGeoPoint(AVISO_LOCALIZACION);

        LatLng pos = new LatLng(point.getLatitude(),point.getLongitude());

        return pos;
    }

    public String getAvisoTelefono() {
        return getString(AVISO_TELEFONO);
    }

    public Boolean getAvisoVisible() {
        return getBoolean(AVISO_VISIBLE);
    }

    public String getLastDate()
    {

        SimpleDateFormat dt = new SimpleDateFormat("dd-MM-yyyy");

        return dt.format(getUpdatedAt());

    }



}
