package com.serrano.aureo.lineaverde.utils;

import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.util.Log;

import java.io.File;
import java.io.FileDescriptor;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * Created by Aureo on 01/12/2015.
 */
public class ExternalFile
{
    //TAG for the logs
    private static final String TAG = "ExternalFile";
    private static final String APP_DIR = "LineVerde";
    private static final String IMG_FILE = "imageAviso.jpg";
    // The new size we want to scale to
    private static final int REQUIRED_SIZE=150;

    public static int saveImageFile(Context context, Bitmap imgBitmap)
    {
        // Create a path where we will place our private file on external
        // storage.
        File file  = new File(context.getExternalFilesDir(APP_DIR), IMG_FILE);

        int result = 0;

        FileOutputStream out = null;
        try {
            out = new FileOutputStream(file);

            //Save the image
            imgBitmap.compress(Bitmap.CompressFormat.JPEG, 100, out);
            result = 1; //OK

        } catch (Exception e)
        {
            Log.e(TAG, "Error saving the image");
            result = -1; //ERROR
        }
        finally {
            try {
                if (out != null)
                {
                    out.close();
                }
            }
            catch (IOException e)
            {
                Log.e(TAG, "Error closing the image file");
            }
        }

        return result;
    }

    public static void deleteImageFile(Context context, File imgFile)
    {
        imgFile.delete();
    }

    public static File hasImageFile(Context context)
    {
        //Check if the image file exists

        File file  = new File(context.getExternalFilesDir(APP_DIR), IMG_FILE);

        if(file.exists())
        {
            return file;
        }
        else
        {
            return null;
        }

    }

    public static Bitmap decodeFile(File f)
    {

        try {
            // Decode image size
            BitmapFactory.Options o = new BitmapFactory.Options();
            o.inJustDecodeBounds = true;
            Bitmap aux = BitmapFactory.decodeStream(new FileInputStream(f), null, o);

            // Find the correct scale value. It should be the power of 2.
            int scale = 1;
            while (o.outWidth / scale / 2 >= REQUIRED_SIZE &&
                    o.outHeight / scale / 2 >= REQUIRED_SIZE) {
                scale *= 2;
            }

            // Decode with inSampleSize
            BitmapFactory.Options o2 = new BitmapFactory.Options();
            o2.inSampleSize = scale;
            return BitmapFactory.decodeStream(new FileInputStream(f), null, o2);
        }
        catch (IOException ex)
        {}

        return null;
    }

    public static File getFilefromUri(Uri uri, Context context)
    {
        String filePath = null;
        Log.d("","URI = "+ uri);
        if (uri != null && "content".equals(uri.getScheme()))
        {
            Cursor cursor = context.getContentResolver().query(uri, new String[] { android.provider.MediaStore.Images.ImageColumns.DATA }, null, null, null);
            cursor.moveToFirst();
            filePath = cursor.getString(0);
            cursor.close();
        }
        else
        {
            filePath = uri.getPath();
        }

        Log.d("","Chosen path = "+ filePath);

        return new File(filePath);
    }
}
